==> colorgb-1.0.tar.gz: colorgb-1.0/README.md <==
[![Visistors](https://visitor-badge.glitch.me/badge?page_id=LyQuid12.colorgb)](https://github.com/LyQuid12/colorgb)
[![Downloads](https://pepy.tech/badge/colorgb)](https://pepy.tech/project/colorgb)
[![PyPI - Version](https://img.shields.io/pypi/v/colorgb?label=PyPI%20Version&logo=pypi)](https://pypi.org/project/colorgb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/colorgb?label=Python%20Version&logo=python)](https://pypi.org/project/colorgb)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/LyQuid12/colorgb?label=Pull%20Requests)](https://github.com/LyQuid12/colorgb/pulls)
[![Discord](https://img.shields.io/discord/887650006977347594?color=blue&label=EterNomm&logo=discord)](https://discord.com/invite/qpT2AeYZRN)

# Colorgb
A Python packages to recoloring default string

### Install
```
pip install colorgb
```

# Examples
- Fore
```py
import colorgb

print(colorgb.fore("Hello!", "green", reset=True))
```

- Backgrounds
```py
import colorgb

print(colorgb.bg("Danger", "red", reset=True))
```

- Style
```
Soon!
```

# License and Copyright
This project under MIT License
```
MIT License

Copyright (c) 2022-present LyQuid

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> colorgb-3.1.tar.gz: colorgb-3.1/README.md <==
[![Visistors](https://visitor-badge.glitch.me/badge?page_id=LyQuid12.colorgb)](https://github.com/LyQuid12/colorgb)
[![Downloads](https://pepy.tech/badge/colorgb)](https://pepy.tech/project/colorgb)
[![PyPI - Version](https://img.shields.io/pypi/v/colorgb?label=PyPI%20Version&logo=pypi)](https://pypi.org/project/colorgb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/colorgb?label=Python%20Version&logo=python)](https://pypi.org/project/colorgb)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/LyQuid12/colorgb?label=Pull%20Requests)](https://github.com/LyQuid12/colorgb/pulls)
[![Discord](https://img.shields.io/discord/887650006977347594?color=blue&label=EterNomm&logo=discord)](https://discord.com/invite/qpT2AeYZRN)

# Colorgb
A Python packages to coloring and styling default terminal text

### Install
```
pip install colorgb
```

# Examples
See at [examples directory](https://github.com/LyQuid12/colorgb/tree/master/examples).

# License and Copyright
This project under MIT License
```
MIT License

Copyright (c) 2022-present LyQuid

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
